@@ -20,6 +20,6 @@ fn main() {
         &mut sp_tree, &mut gene_trees, &mut global_roots);
     recphyloxml_processing(&mut sp_tree, &mut gene_trees, &mut options, &config, true,
          &transfers, "read_recphyloxml_free_living_reconciliated.svg".to_string());
-    println!("Please open output file 'read_recphyloxml_free_living_reconciliate' with your browser");
+    println!("Please open output file 'read_recphyloxml_free_living_reconciliated.svg' with your browser");
 
 }
