@@ -366,7 +366,7 @@ pub fn draw_sptree_gntrees (
             // Dessine le chemin du noeud a son pere
             match index.parent {
                  Some(p) => {
-                     let n = &gene_trees[idx_rcgen].arena[p];
+                    let n = &gene_trees[idx_rcgen].arena[p];
                      // La forme du chemin depend de l'evenement
                      let chemin = match index.is_a_transfert {
                         true => {
@@ -376,6 +376,7 @@ pub fn draw_sptree_gntrees (
                                     true => "0.0".to_string(),
                                     false => config.gene_opacity.to_string(),
                             };
+
                             // Verifie que le parent est bien un branchingout
                             match n.e {
                                 Event::BranchingOut => get_chemin_transfer(index.x,index.y,
@@ -390,9 +391,39 @@ pub fn draw_sptree_gntrees (
                                         transfer_opacity,
                                         config.bezier.to_string().parse::<f32>().unwrap(),
                                         2),
-                                _ => panic!("Wrong recPhyloXML feature.
-                                The father node should be BranchingOut or
-                                BifurcationOut, but I found a {:?}\n{:?}",n.e,n),
+                                _ => {
+                                    // Si le noaud courant est vrituel,je peux tracer quand  meme
+                                    // ( a verfier)
+                                    if index.virtualsvg {
+                                        get_chemin_transfer(index.x,index.y,
+                                                n.x,n.y,
+                                                gene_color.to_string(),
+                                                transfer_opacity,
+                                                config.bezier.to_string().parse::<f32>().unwrap(),
+                                                1)
+                                    }
+                                    else {
+                                        // Si c'est le pere qui est virtuel on va voir le grand PERE
+                                        if n.virtualsvg {
+                                            let ppp = n.parent.expect("[draw_sptree_gntrees] ERROR: Unable to get the father of the node");
+                                            let nnn = &gene_trees[idx_rcgen].arena[ppp];
+                                            if nnn.e != Event::BranchingOut && nnn.e != Event::BifurcationOut {
+                                                panic!("Wrong recPhyloXML feature in tree # {}.The (grand)father node should be BranchingOut or BifurcationOut, but I found a {:?} Father node: {:?}\nCurrent node: {:?}",
+                                                idx_rcgen,nnn.e,nnn,index);
+                                            }
+                                            get_chemin_transfer(index.x,index.y,
+                                                    nnn.x,nnn.y,
+                                                    gene_color.to_string(),
+                                                    1.0.to_string(),
+                                                    config.bezier.to_string().parse::<f32>().unwrap(),
+                                                    1)
+                                        }
+                                        else {
+                                            panic!("Wrong recPhyloXML feature in tree # {}.The father node should be BranchingOut or BifurcationOut, but I found a {:?} Father node: {:?}\nCurrent node: {:?}",
+                                            idx_rcgen,n.e,n,index);
+                                        }
+                                    }
+                                },
                             }
                         },
                         false => {
